@@ -19,7 +19,7 @@ int boundary_sort3=10000;
 #include "CoinHelperFunctions.hpp"
 #include "CoinSort.hpp"
 // History since 1.0 at end
-#define CLPVERSION "1.06.00"
+#define CLPVERSION "1.10.0"
 
 #include "CoinMpsIO.hpp"
 #include "CoinFileIO.hpp"
@@ -52,6 +52,9 @@ int boundary_sort3=10000;
 #ifdef TAUCS_BARRIER
 #define FOREIGN_BARRIER
 #endif
+#ifdef MUMPS_BARRIER
+#define FOREIGN_BARRIER
+#endif
 
 static double totalTime=0.0;
 static bool maskMatches(const int * starts, char ** masks,
@@ -597,7 +600,7 @@ main (int argc, const char *argv[])
 		  }
 		}
 		if (tryIt) {
-		  model2 = ((ClpSimplexOther *) model2)->dualOfModel(fractionRow,fractionColumn);
+		  model2 = static_cast<ClpSimplexOther *> (model2)->dualOfModel(fractionRow,fractionColumn);
 		  if (model2) {
 		    printf("Dual of model has %d rows and %d columns\n",
 			   model2->numberRows(),model2->numberColumns());
@@ -733,9 +736,10 @@ main (int argc, const char *argv[])
               }
 #ifdef CLP_MULTIPLE_FACTORIZATIONS   
 	      int denseCode = parameters[whichParam(DENSE,numberParameters,parameters)].intValue();
-	      if (denseCode>=model2->numberRows()) {
-		model2->factorization()->goDense();
-	      }
+	      model2->factorization()->setGoDenseThreshold(denseCode);
+	      int smallCode = parameters[whichParam(SMALLFACT,numberParameters,parameters)].intValue();
+	      model2->factorization()->setGoSmallThreshold(smallCode);
+	      model2->factorization()->goDenseOrSmall(model2->numberRows());
 #endif
               try {
                 status=model2->initialSolve(solveOptions);
@@ -745,15 +749,14 @@ main (int argc, const char *argv[])
                 status=-1;
               }
               if (dualize) {
-                int returnCode=((ClpSimplexOther *) models+iModel)->restoreFromDual(model2);
+                int returnCode=static_cast<ClpSimplexOther *> (models+iModel)->restoreFromDual(model2);
 		if (model2->status()==3)
 		  returnCode=0;
                 delete model2;
 		if (returnCode&&dualize!=2) {
-		  CoinSighandler_t saveSignal=SIG_DFL;
 		  currentModel = models+iModel;
 		  // register signal handler
-		  saveSignal = signal(SIGINT,signal_handler);
+		  signal(SIGINT,signal_handler);
 		  models[iModel].primal(1);
 		  currentModel=NULL;
 		}
@@ -957,7 +960,7 @@ main (int argc, const char *argv[])
 		  // Go to canned file if just input file
 		  if (CbcOrClpRead_mode==2&&argc==2) {
 		    // only if ends .mps
-		    char * find = (char *)strstr(fileName.c_str(),".mps");
+		    char * find = const_cast<char *>(strstr(fileName.c_str(),".mps"));
 		    if (find&&find[4]=='\0') {
 		      find[1]='p'; find[2]='a';find[3]='r';
 		      FILE *fp=fopen(fileName.c_str(),"r");
@@ -1039,7 +1042,7 @@ main (int argc, const char *argv[])
 		bool deleteModel2=false;
 		ClpSimplex * model2 = models+iModel;
 		if (dualize&&dualize<3) {
-		  model2 = ((ClpSimplexOther *) model2)->dualOfModel();
+		  model2 = static_cast<ClpSimplexOther *> (model2)->dualOfModel();
 		  printf("Dual of model has %d rows and %d columns\n",
 			 model2->numberRows(),model2->numberColumns());
 		  model2->setOptimizationDirection(1.0);
@@ -1661,6 +1664,27 @@ clp watson.mps -\nscaling off\nprimalsimplex"
 		fp=fopen(fileName.c_str(),"w");
 	      }
 	      if (fp) {
+		// Write solution header (suggested by Luigi Poderico)
+		double objValue = models[iModel].getObjValue()*models[iModel].getObjSense();
+		int iStat = models[iModel].status();
+		if (iStat==0) {
+		  fprintf(fp, "optimal\n" );
+		} else if (iStat==1) {
+		  // infeasible
+		  fprintf(fp, "infeasible\n" );
+		} else if (iStat==2) {
+		  // unbounded
+		  fprintf(fp, "unbounded\n" );
+		} else if (iStat==3) {
+		  fprintf(fp, "stopped on iterations or time\n" );
+		} else if (iStat==4) {
+		  fprintf(fp, "stopped on difficulties\n" );
+		} else if (iStat==5) {
+		  fprintf(fp, "stopped on ctrl-c\n" );
+		} else {
+		  fprintf(fp, "status unknown\n" );
+		}
+		fprintf(fp, "Objective value %15.8g\n", objValue);
 		// make fancy later on
 		int iRow;
 		int numberRows=models[iModel].numberRows();
@@ -1940,7 +1964,7 @@ static void breakdown(const char * name, int numberLook, const double * region)
     1.0,
     1.0e1,1.0e2,1.0e3,1.0e4,1.0e5,1.0e8,1.0e11,1.0e15,
     COIN_DBL_MAX};
-  int nRanges = (int) (sizeof(range)/sizeof(double));
+  int nRanges = static_cast<int> (sizeof(range)/sizeof(double));
   int * number = new int[nRanges];
   memset(number,0,nRanges*sizeof(int));
   int * numberExact = new int[nRanges];
@@ -2160,7 +2184,7 @@ static void statistics(ClpSimplex * originalModel, ClpSimplex * model)
   }
   printf("Column breakdown:\n");
   int k;
-  for (k=0;k<(int) (sizeof(cType)/sizeof(int));k++) {
+  for (k=0;k<static_cast<int> (sizeof(cType)/sizeof(int));k++) {
     printf("%d of type %s ",cType[k],cName[k].c_str());
     if (((k+1)%3)==0)
       printf("\n");
@@ -2168,7 +2192,7 @@ static void statistics(ClpSimplex * originalModel, ClpSimplex * model)
   if ((k%3)!=0)
     printf("\n");
   printf("Row breakdown:\n");
-  for (k=0;k<(int) (sizeof(rType)/sizeof(int));k++) {
+  for (k=0;k<static_cast<int> (sizeof(rType)/sizeof(int));k++) {
     printf("%d of type %s ",rType[k],rName[k].c_str());
     if (((k+1)%3)==0)
       printf("\n");
