@@ -783,7 +783,7 @@ ClpNonLinearCost::checkInfeasibilities(double oldTolerance)
     // nonbasic should be at a valid bound
     for (iSequence=0;iSequence<numberTotal;iSequence++) {
       double value=solution[iSequence];
-      int iStatus = status_[iSequence];
+      unsigned char iStatus = status_[iSequence];
       assert (currentStatus(iStatus)==CLP_SAME);
       double lowerValue=lower[iSequence];
       double upperValue=upper[iSequence];
@@ -819,6 +819,7 @@ ClpNonLinearCost::checkInfeasibilities(double oldTolerance)
           } else {
             // below
             newWhere=CLP_BELOW_LOWER;
+	    assert (fabs(lowerValue)<1.0e100);
             double infeasibility = lowerValue-value-primalTolerance;
             sumInfeasibilities_ += infeasibility;
             largestInfeasibility_ = CoinMax(largestInfeasibility_,infeasibility);
@@ -988,7 +989,7 @@ ClpNonLinearCost::feasibleBounds()
     double * cost = model_->costRegion();
     int numberTotal = numberColumns_+numberRows_;
     for (iSequence=0;iSequence<numberTotal;iSequence++) {
-      int iStatus = status_[iSequence];
+      unsigned char iStatus = status_[iSequence];
       assert (currentStatus(iStatus)==CLP_SAME);
       double lowerValue=lower[iSequence];
       double upperValue=upper[iSequence];
@@ -997,6 +998,7 @@ ClpNonLinearCost::feasibleBounds()
       if (iWhere==CLP_BELOW_LOWER) {
         lowerValue=upperValue;
         upperValue=bound_[iSequence];
+	assert (fabs(lowerValue)<1.0e100);
       } else if (iWhere==CLP_ABOVE_UPPER) {
         upperValue=lowerValue;
         lowerValue=bound_[iSequence];
@@ -1059,7 +1061,7 @@ ClpNonLinearCost::goThru(int numberInArray, double multiplier,
       int iSequence = pivotVariable[iRow];
       double alpha = multiplier*array[iRow];
       double value = solution[iSequence];
-      int iStatus = status_[iSequence];
+      unsigned char iStatus = status_[iSequence];
       int iWhere = currentStatus(iStatus);
       if (iWhere==CLP_SAME)
         iWhere = originalStatus(iStatus);
@@ -1145,7 +1147,7 @@ ClpNonLinearCost::goBack(int numberInArray, const int * index,
       int iRow = index[i];
       int iSequence = pivotVariable[iRow];
       double value = solution[iSequence];
-      int iStatus = status_[iSequence];
+      unsigned char iStatus = status_[iSequence];
       int iWhere = currentStatus(iStatus);
       int original = originalStatus(iStatus);
       assert (iWhere!=CLP_SAME);
@@ -1255,7 +1257,7 @@ ClpNonLinearCost::checkInfeasibilities(int numberInArray, const int * index)
       int iRow = index[i];
       int iSequence = pivotVariable[iRow];
       double value=solution[iSequence];
-      int iStatus = status_[iSequence];
+      unsigned char iStatus = status_[iSequence];
       assert (currentStatus(iStatus)==CLP_SAME);
       double lowerValue=lower[iSequence];
       double upperValue=upper[iSequence];
@@ -1265,6 +1267,7 @@ ClpNonLinearCost::checkInfeasibilities(int numberInArray, const int * index)
         lowerValue=upperValue;
         upperValue=bound_[iSequence];
         numberInfeasibilities_--;
+	assert (fabs(lowerValue)<1.0e100);
       } else if (iWhere==CLP_ABOVE_UPPER) {
         upperValue=lowerValue;
         lowerValue=bound_[iSequence];
@@ -1279,6 +1282,7 @@ ClpNonLinearCost::checkInfeasibilities(int numberInArray, const int * index)
         } else {
           // below
           newWhere=CLP_BELOW_LOWER;
+	  assert (fabs(lowerValue)<1.0e100);
           costValue -= infeasibilityWeight_;
           numberInfeasibilities_++;
         }
@@ -1368,7 +1372,7 @@ ClpNonLinearCost::checkChanged(int numberInArray, CoinIndexedVector * update)
       int iRow = index[i];
       int iSequence = pivotVariable[iRow];
       double value=solution[iSequence];
-      int iStatus = status_[iSequence];
+      unsigned char iStatus = status_[iSequence];
       assert (currentStatus(iStatus)==CLP_SAME);
       double lowerValue=lower[iSequence];
       double upperValue=upper[iSequence];
@@ -1378,6 +1382,7 @@ ClpNonLinearCost::checkChanged(int numberInArray, CoinIndexedVector * update)
         lowerValue=upperValue;
         upperValue=bound_[iSequence];
         numberInfeasibilities_--;
+	assert (fabs(lowerValue)<1.0e100);
       } else if (iWhere==CLP_ABOVE_UPPER) {
         upperValue=lowerValue;
         lowerValue=bound_[iSequence];
@@ -1394,6 +1399,7 @@ ClpNonLinearCost::checkChanged(int numberInArray, CoinIndexedVector * update)
           newWhere=CLP_BELOW_LOWER;
           costValue -= infeasibilityWeight_;
           numberInfeasibilities_++;
+	  assert (fabs(lowerValue)<1.0e100);
         }
       } else {
         // above
@@ -1511,7 +1517,7 @@ ClpNonLinearCost::setOne(int iSequence, double value)
     double * upper = model_->upperRegion();
     double * lower = model_->lowerRegion();
     double * cost = model_->costRegion();
-    int iStatus = status_[iSequence];
+    unsigned char iStatus = status_[iSequence];
     assert (currentStatus(iStatus)==CLP_SAME);
     double lowerValue=lower[iSequence];
     double upperValue=upper[iSequence];
@@ -1521,6 +1527,7 @@ ClpNonLinearCost::setOne(int iSequence, double value)
       lowerValue=upperValue;
       upperValue=bound_[iSequence];
       numberInfeasibilities_--;
+      assert (fabs(lowerValue)<1.0e100);
     } else if (iWhere==CLP_ABOVE_UPPER) {
       upperValue=lowerValue;
       lowerValue=bound_[iSequence];
@@ -1537,6 +1544,7 @@ ClpNonLinearCost::setOne(int iSequence, double value)
         newWhere=CLP_BELOW_LOWER;
         costValue -= infeasibilityWeight_;
         numberInfeasibilities_++;
+	assert (fabs(lowerValue)<1.0e100);
       }
     } else {
       // above
@@ -1712,7 +1720,7 @@ ClpNonLinearCost::setOneOutgoing(int iSequence, double & value)
     double * upper = model_->upperRegion();
     double * lower = model_->lowerRegion();
     double * cost = model_->costRegion();
-    int iStatus = status_[iSequence];
+    unsigned char iStatus = status_[iSequence];
     assert (currentStatus(iStatus)==CLP_SAME);
     double lowerValue=lower[iSequence];
     double upperValue=upper[iSequence];
@@ -1731,6 +1739,7 @@ ClpNonLinearCost::setOneOutgoing(int iSequence, double & value)
       lowerValue=upperValue;
       upperValue=bound_[iSequence];
       numberInfeasibilities_--;
+      assert (fabs(lowerValue)<1.0e100);
     } else if (iWhere==CLP_ABOVE_UPPER) {
       upperValue=lowerValue;
       lowerValue=bound_[iSequence];
@@ -1750,6 +1759,7 @@ ClpNonLinearCost::setOneOutgoing(int iSequence, double & value)
         newWhere=CLP_BELOW_LOWER;
         costValue -= infeasibilityWeight_;
         numberInfeasibilities_++;
+	assert (fabs(lowerValue)<1.0e100);
       }
     } else {
       // above
@@ -1822,6 +1832,7 @@ ClpNonLinearCost::nearest(int iSequence, double solutionValue)
     if (iWhere==CLP_BELOW_LOWER) {
       lowerValue=upperValue;
       upperValue=bound_[iSequence];
+      assert (fabs(lowerValue)<1.0e100);
     } else if (iWhere==CLP_ABOVE_UPPER) {
       upperValue=lowerValue;
       lowerValue=bound_[iSequence];
@@ -1895,6 +1906,7 @@ ClpNonLinearCost::validate()
     if (iWhere==CLP_BELOW_LOWER) {
       lowerValue=upperValue;
       upperValue=bound_[iSequence];
+      assert (fabs(lowerValue)<1.0e100);
       costValue -= infeasibilityCost;
       assert (value<=lowerValue-primalTolerance);
       numberInfeasibilities++;
